@@ -27,16 +27,16 @@ role PDF::ExtGState
     has Int $.OPM is entry(:alias<overprint-mode>);              # (Optional; PDF 1.3) The overprint mode
     has @.Font is entry(:len(2));          # (Optional; PDF 1.3) An array of the form [ font size ], where font is an indirect reference to a font dictionary and size is a number expressed in text space units.
 
-    has PDF::Function $.BG is entry(:alias<black-generation-old>);             # (Optional) The black-generation function, which maps the interval [ 0.0 1.0 ] to the interval [ 0.0 1.0 ]
-    my subset FunctionOrName where PDF::Function|PDF::COS::Name;
-    has FunctionOrName $.BG2 is entry(:alias<black-generation>);                # (Optional; PDF 1.3) Same as BG except that the value may also be the name Default, denoting the black-generation function that was in effect at the start of the page
+    my subset XFerFunction where PDF::Function|PDF::COS::Name;
+    has XFerFunction $.BG is entry(:alias<black-generation-old>);             # (Optional) The black-generation function, which maps the interval [ 0.0 1.0 ] to the interval [ 0.0 1.0 ]
+    has XFerFunction $.BG2 is entry(:alias<black-generation>);                # (Optional; PDF 1.3) Same as BG except that the value may also be the name Default, denoting the black-generation function that was in effect at the start of the page
     # If both BG and BG2 are present in the same graphics state parameter dictionary, BG2 takes precedence.
 
-    has PDF::Function $.UCR is entry(:alias<under-color-removal-old>);          # (Optional) The undercolor-removal function, which maps the interval [ 0.0 1.0 ] to the interval [ −1.0 1.0 ]
-    has FunctionOrName $.UCR2 is entry(:alias<under-color-removal>);            # (Optional; PDF 1.3) Same as UCR except that the value may also be the name Default, denoting the undercolor-removal function that was in effect at the start of the page.
+    has XFerFunction $.UCR is entry(:alias<under-color-removal-old>);          # (Optional) The undercolor-removal function, which maps the interval [ 0.0 1.0 ] to the interval [ −1.0 1.0 ]
+    has XFerFunction $.UCR2 is entry(:alias<under-color-removal>);            # (Optional; PDF 1.3) Same as UCR except that the value may also be the name Default, denoting the undercolor-removal function that was in effect at the start of the page.
 
-    has FunctionOrName @.TR is entry(:alias<transfer-function-old>, :array-or-item);            # (Optional) The transfer function, which maps the interval [ 0.0 1.0 ] to the interval [ 0.0 1.0 ]
-    has FunctionOrName @.TR2 is entry(:alias<transfer-function>, :array-or-item);               # (Optional; PDF 1.3) Same as TR except that the value may also be the name Default, denoting the transfer function that was in effect at the start of the page.
+    has XFerFunction @.TR is entry(:alias<transfer-function-old>, :array-or-item);            # (Optional) The transfer function, which maps the interval [ 0.0 1.0 ] to the interval [ 0.0 1.0 ]
+    has XFerFunction @.TR2 is entry(:alias<transfer-function>, :array-or-item);               # (Optional; PDF 1.3) Same as TR except that the value may also be the name Default, denoting the transfer function that was in effect at the start of the page.
 
     has $.HT is entry(:alias<halftone>) where Hash|'Default';    # (Optional) The halftone dictionary or stream or the name 'Default'
     has Numeric $.FL is entry(:alias<flatness-tolerance>);       # (Optional; PDF 1.3) The flatness tolerance
