@@ -9,12 +9,12 @@ use PDF::Class::Type;
 class PDF::Font
     is PDF::COS::Dict
     does PDF::Content::Font
-    does PDF::Class::Type {
+    does PDF::Class::Type::Subtyped {
 
     use PDF::COS::Tie;
     use PDF::COS::Name;
 
-    has PDF::COS::Name $.Type is entry(:required) where 'Font';
-    has PDF::COS::Name $.Subtype is entry(:required);
+    has PDF::COS::Name $.Type is entry(:required, :alias<type>) where 'Font';
+    has PDF::COS::Name $.Subtype is entry(:required, :alias<subtype>);
 
 }
