@@ -1,11 +1,11 @@
 use v6;
 
-use PDF::COS::Dict;
+use PDF::COS::Tie::Hash;
 
 #| /Type /FontDescriptor - the FontDescriptor dictionary
 
-class PDF::FontDescriptor
-    is PDF::COS::Dict {
+role PDF::FontDescriptor
+    does PDF::COS::Tie::Hash {
 
     use PDF::COS::Tie;
     use PDF::COS::Name;
