@@ -12,6 +12,6 @@ class PDF::FontFile
     use PDF::COS::Name;
     use PDF::COS::Tie;
 
-    my subset Subtype of PDF::COS::Name where 'Type1C'|'CIDFontType0C'|'OpenType';
-    has Subtype $.Subtype is entry(:required);
+    my subset FontType of PDF::COS::Name where 'Type1C'|'CIDFontType0C'|'OpenType';
+    has FontType $.Subtype is entry(:required);
 }
