@@ -6,7 +6,7 @@ use PDF::Class::Type;
 # /Type /Group - group attributes dictionary
 class PDF::Group
     is PDF::COS::Dict
-    does PDF::Class::Type['Type','S'] {
+    does PDF::Class::Type::Subtyped {
 
     # see [PDF 32000 Table 96 – Entries Common to all Group Attributes Dictionaries]
     ## use ISO_32000::Group_Attributes_common;
@@ -14,6 +14,6 @@ class PDF::Group
     use PDF::COS::Tie;
     use PDF::COS::Name;
 
-    has PDF::COS::Name $.Type is entry where 'Group';
-    has PDF::COS::Name $.S is entry;
+    has PDF::COS::Name $.Type is entry(:alias<type>) where 'Group';
+    has PDF::COS::Name $.S is entry(:alias<subtype>);
 }
