@@ -3,7 +3,7 @@ use v6;
 use PDF::COS::Dict;
 use PDF::Class::Type;
 
-# /Type /OCMD - Optional Content Marked Content
+# /Type /OCMD - Optional Content Membership Dictionary
 class PDF::OCMD
     is PDF::COS::Dict
     does PDF::Class::Type {
@@ -19,7 +19,7 @@ class PDF::OCMD
     use PDF::COS::TextString;
     use PDF::OCG;
 
-    has PDF::COS::Name $.Type is entry(:required) where 'OCMD';
+    has PDF::COS::Name $.Type is entry(:required, :alias<type>) where 'OCMD';
 
     has PDF::OCG @.OCGs is entry(:array-or-item); # (Optional) A dictionary or array of dictionaries specifying the optional content groups whose states shall determine the visibility of content controlled by this membership dictionary. Null values or references to deleted objects shall be ignored. If this entry is not present, is an empty array, or contains references only to null or deleted objects, the membership dictionary shall have no effect on the visibility of any content.
     has PDF::COS::Name $.P is entry(:alias<visibility-policy>, :default<AnyOn>) where /^[All|Any][Off|On]$/; # (Optional) A name specifying the visibility policy for content belonging to this membership dictionary. Valid values shall be:
