@@ -25,7 +25,7 @@ class PDF::Pages
     has PDF::Content::PageNode @.Kids is entry(:required, :indirect);  # (Required) An array of indirect references to the immediate children of this node. The children may be page objects or other page tree nodes.
     has UInt $.Count is entry(:required);   # (Required) The number of leaf nodes (page objects) that are descendants of this node within the page tree.
     has PDF::Resources $.Resources is entry(:inherit);
-    has Int $.Rotate is entry(:inherit) where { $_ %% 90 };     # (Optional; inheritable) The number of degrees by which the page should be rotated clockwise when displayed or printed
+    has Int $.Rotate is entry(:inherit, :alias<rotate>) where { $_ %% 90 };     # (Optional; inheritable) The number of degrees by which the page should be rotated clockwise when displayed or printed
     #| inheritable page properties
     has Numeric @.MediaBox is entry(:inherit,:len(4));
     has Numeric @.CropBox is entry(:inherit,:len(4));
