@@ -22,7 +22,15 @@ role PDF::Signature
     has PDF::COS::ByteString $.Contents is entry(:required); # (Required) The signature value. When ByteRange is present, the value shall be a hexadecimal string representing the value of the byte range digest. For public-key signatures, Contents should be either a DER-encoded PKCS#1 binary data object or a DER-encoded PKCS#7 binary data object.
     has PDF::COS::ByteString @.Cert is entry(:array-or-item); # (Required when SubFilter is adbe.x509.rsa_sha1) An array of byte strings that shall represent the X.509 certificate chain used when signing and verifying signatures that use public-key cryptography, or a byte string if the chain has only one entry. The signing certificate shall appear first in the array; it shall be used to verify the signature value in Contents, and the other certificates shall be used to verify the authenticity of the signing certificate.
     has UInt @.ByteRange is entry; # (Required for all signatures that are part of a signature field and usage rights signatures referenced from the UR3 entry in the permissions dictionary) An array of pairs of integers (starting byte offset, length in bytes) that shall describe the exact byte range for the digest calculation. Multiple discontiguous byte ranges shall be used to describe a digest that does not include the signature value (the Contents entry) itself.
-    has Hash @Reference is entry; # (Optional; PDF 1.5) An array of signature reference dictionaries.
+    my role Reference does PDF::COS::Tie::Hash {
+        has PDF::COS::Name $.Type is entry where 'SigRef'; # (Optional) The type of PDF object that this dictionary describes; if present, shall be SigRef for a signature reference dictionary.
+        my subset TransformMethod of PDF::COS::Name where 'DocMDP'|'R'|'UR'|'FieldMPD';
+        has TransformMethod $.TransformMethod is entry(:required); # The name of the transform method (see Section that shall guide the modification analysis that takes place when the signature is validated.
+        has $.Data is entry(:indirect); # (Required when TransformMethod is FieldMDP) An indirect reference to the object in the document upon which the object modification analysis should be performed.
+        has Hash $.TransformParams is entry; # (Optional) A dictionary specifying transform parameters (variable data) for the transform method specified by TransformMethod.
+        has PDF::COS::Name $.DigestMethod is entry; # Optional; PDF 1.5 required) A name identifying the algorithm that shall be used when computing the digest. Valid values are MD5 and SHA1. Default value: MD5. For security reasons, MD5 should not be used.
+    }
+    has Reference @Reference is entry; # (Optional; PDF 1.5) An array of signature reference dictionaries.
     has Int @.Changes is entry(:len(3)); # (Optional) An array of three integers that shall specify changes to the document that have been made between the previous signature and this signature: in this order, the number of pages altered, the number of fields altered, and the number of fields filled in.
     # The ordering of signatures shall be determined by the value of ByteRange. Since each signature results in an incremental save, later signatures have a greater length value.
     has PDF::COS::TextString $.Name is entry; # (Optional) The name of the person or authority signing the document. This value should be used only when it is not possible to extract the name from the signature.
